function SolveBigAllSpeciespCyton
   
    maxGens = 9;
    %maximum time for simulations
    maxTime=144*60;  % minutes
    N=50;  % starting cells
    replicates = 1;

    parpool('local',2);


    paramsToRun = {};
    paramNames = {};
    
    parameters= {'Tdiv0mean';'Tdiv0var';'Tdie0mean';'Tdie0var';'Tdiv1pmean';'Tdiv1pvar';'pF'};

     paramsToRun{end+1}=[59.495*60,0.1944*60,70.882*60,0.762*60,9.431*60,0.481*60,0.868];                         %
     paramNames{end+1}='7 param cyton'; %experiment 1  doi: 10.1073/pnas.0700026104

    tic;

    for k = 1:numel(paramsToRun)
        experiment = experimentConditions(maxTime,paramsToRun{k});
        solutions ={};

        for rep = 1:replicates
            label = sprintf('%s_%d',paramNames{k},rep);
            for i = 1:length(parameters)
                label= sprintf('%s %s=%2.2f',label,parameters{i},paramsToRun{k}(i));
            end
            fprintf(1,'%s\n',label);
            solutions{end+1}=runSolution(experiment,N,maxTime,maxGens);
            
            experiment_label=sprintf('%s_%d %s',paramNames{k},rep,datestr(now,'mmmm dd, yyyy HH-MM-SS-FFF'));
            movefile('unprocessedCells',strcat('unprocessedCells',experiment_label));

            movefile('processedCells',strcat('processedCells',experiment_label));
            movefile('Checkpoints',strcat('Checkpoints',experiment_label));
        end
        
        saveSolutions(solutions,N,maxTime,maxGens,paramNames{k},label);
    end
    toc

    clear all;
    
end

function sol= runSolution(experiment, N, maxTime, maxGens)
    SEE = 0;
    
    fprintf(1,'\nChecking for saved progress\n');
    
    
    
    progressFiles=fullfile('Checkpoints','*.mat');
    solsToLoad=dir(progressFiles);
        fprintf(1,'\nNo saved solution files found, starting new analysis\n');
        sol = duplicate(experiment);    
        sol.counts=ones(ceil(maxTime/30),maxGens);
        sol.fullCounts = zeros(maxTime,maxGens); % total count as a function of gen and time
        sol.integralCounts = zeros(maxGens); % total number of generation cells
        sol.h24counts = zeros(maxGens); % total number of generation cells
        %average concentrations over time
        sol.raverages = zeros(100,144,maxGens);
        sol.qaverages = zeros(100,144,maxGens);
        sol.Tdivs= zeros(maxGens,ceil(maxTime/60)); % in terms of hours
        sol.Tdecides = zeros(maxGens,ceil(maxTime/60));
        sol.Tdies= zeros(maxGens,ceil(maxTime/60));
        sol.TdivTimes = cell(1);
        sol.TdieTimes = cell(1);
        sol.TdecideTimes = cell(1);
        sol.TdivMothers = cell(1);
        sol.TdieMothers = cell(1);
        sol.TdecideMothers = cell(1);    
        for i = 1:maxGens
            sol.TdivTimes{end+1}=cell(1);
            sol.TdieTimes{end+1}=cell(1);
            sol.TdecideTimes{end+1}=cell(1);
            sol.TdivMothers{end+1}=cell(1);
            sol.TdieMothers{end+1}=cell(1);
            sol.TdecideMothers{end+1}=cell(1);
        end

        sol.divbag = {};
        sol.diebag ={};
        sol.decidebag = {};
        
        sol.gs = zeros(maxGens); % fraction that grow to larger than v0+1.75 their starting size or to a size of 4 (both dividers and non-dividers)
        sol.fs = zeros(maxGens); % fraction that divides (assume that the rest will eventually die)
        sol.tp = zeros(maxGens); % fraction that grows and divides
        sol.fp = zeros(maxGens); % fraction that grows but dies
        sol.tn = zeros(maxGens); % fraction that doesn't grow and dies
        sol.fn = zeros(maxGens); % fraction that doesn't grow but divides
        sol.tp24 = zeros(maxGens); % fraction that grows and divides 24
        sol.fp24 = zeros(maxGens); % fraction that grows but dies 24
        sol.tn24 = zeros(maxGens); % fraction that doesn't grow and dies 24
        sol.fn24 = zeros(maxGens); % fraction that doesn't grow but divides 24
      
        %Need to store lineage tree information for plotting modeling lineage trees.
        %CellID, motherID fateTime
        sol.lineageInfo=zeros(3,N);

        
    end
    
    %all of the cells currently waiting to be computed
    cells = cell(N,1);

    %Store how many total cells have been processed, this is used for the
    %plots of individual NFkB species to be stored correctly.
    totalCellNumberCurrentlyProcessed=1;
    
    TdivFits = zeros(maxGens,6); %lognormal fits: E[Tdiv]fit, s.d.[Tdiv]fit, E[Tdiv]min, E[Tdiv]max, s.d.[Tdiv]min, s.d.[Tdiv]max
    TdieFits = zeros(maxGens,6);

    filesToProcess=fullfile('unprocessedCells','*.mat');
    cellsToProcess=dir(filesToProcess);
    
    %if we need to increase the size of the timecourse variables we're
    %storing let's do it here.

    
    if ~length(cellsToProcess)>0
    
        fprintf(1,'Initializing: %d cells\n',N);
        parfor i=1:N  
            %%%%% RUN TO INITIALIZE THE PERSISTENT VARS %%%%%%%%%%
            cells{i}.PHASE = 2;
            cells{i}.birthday=0;  % start at 0 hours
            cells{i}.gen = 1;  % undivided
            cells{i}.id =i;
            cells{i}.parent =0;
            cells{i}.maxgen=maxGens;
        end
            fprintf('\nSaving cells to cells.out and processing initial cells\n');
            mkdir('unprocessedCells');
            mkdir('processedCells');
            save('unprocessedCells/cells.mat','cells');
    end
    cell_id=N+1;
    mkdir('Checkpoints');
    
    while ~isempty(dir(fullfile('unprocessedCells','*.mat')))
        
        %let's load all files in the unprocessedCells folder and process
        %each one in turn
        filesToProcess=fullfile('unprocessedCells','*.mat');
        cellsToProcess=dir(filesToProcess);
    
        for k=1:length(cellsToProcess)
            load(fullfile('unprocessedCells',cellsToProcess(k).name));
            
            if length(cells)==0
                fprintf('\nEmpty saved cells found ignoring\n');
                mkdir('EmptyCells');
                fprintf(1,'\n Moving file to empty folder: %s\n',fullfile('EmptyCells',cellsToProcess(k).name));
                movefile(fullfile('unprocessedCells',cellsToProcess(k).name),fullfile('EmptyCells',cellsToProcess(k).name));
                continue;
            end
            stridelength=ceil(length(cells)/100);
            fprintf(1,'\nProcessing %d cells\n',length(cells));
            for stride=1:stridelength
                celllength = min(100,length(cells)-(stride-1)*100);
                %parfor temporary=((stride-1)*100+1):((stride-1)*100)+celllength                   
                parfor temporary=((stride-1)*100+1):((stride-1)*100)+celllength                   
                    cells{temporary}.SIM_TIME=max(1,(maxTime)-cells{temporary}.birthday);
                    cells{temporary}.START_TIME = cells{temporary}.birthday;
                    %cells{temporary}.v=run_cell(cells{temporary}.v);
                    tdiv = 999999;
                    tdie = 999999;
                    tdecide=999999;
                    [tdiv,tdie]=getCellFate(experiment,cells{temporary}.gen);
                    if(tdie>maxTime)
                        tdie=maxTime
                    end
                    tdecide=min([tdie,tdiv]);

                    cells{temporary}.tdiv = tdiv;
                    cells{temporary}.tdie = tdie;
                    cells{temporary}.tdecide= tdecide;
                    %cells{temporary}.maxgen=maxGens;
                end
            end
            cells2={};    
            cell_count = 0;
            real_count = 0;

            numdivs = 0;
            numdeaths = 0;
            numdecides = 0;

            sol.deaths = [];
            sol.divs = [];
            sol.decides = [];
            dividers = 0;
            nondividers = 0;
            Cgen = 0;        
        
%             printf('\nSaving cells to cells.out which contains %d cells\n',length(cells));
%             save('cells.out','cells');
        
            while ~isempty(cells)
                theCell = cells{1};
                
                if SEE == 1;
                    figure(1);
                    subplot(3,3,theCell.gen);
                    hold on;
                end
                
                real_count=real_count+1;

                sol.integralCounts(theCell.gen)=sol.integralCounts(theCell.gen)+1;
                
                bindex=ceil(theCell.birthday); % birth index
                index = ceil(theCell.SIM_TIME);    % length of the time course
                Cgen = theCell.gen;
                for i=((bindex)+1):30:index+bindex % for each time point in the timecourse
                    if i-bindex > 0 && i <= maxTime  
                        sol.counts(ceil(i/30),theCell.gen)=sol.counts(ceil(i/30),theCell.gen)+1; % add the counts to the summary
                    end
                end
                for i=((bindex)+1):1:(index+bindex) % for each time point in the timecourse
                    if i-bindex > 0 && i <= maxTime  
                        sol.fullCounts(i,theCell.gen)=sol.fullCounts(i,theCell.gen)+1; % add the counts to the summary
                    end
                end
                if theCell.tdecide <= maxTime;
                    sol.Tdecides(theCell.gen,ceil(theCell.tdecide/60))=sol.Tdecides(theCell.gen,ceil(theCell.tdecide/60))+1;
                    sol.decides(end+1)=ceil(theCell.tdecide/60);
                    sol.gs(theCell.gen)=sol.gs(theCell.gen)+1;
                    numdecides=numdecides+1;
                end

                if((theCell.tdie < theCell.tdiv)||(theCell.gen+1>maxGens))
                    % cell died
                    %fprintf(1,'A cell died at time %f it was %f minutes old. Total cells %d\n',theCell.tdie+theCell.birthday,theCell.tdie,length(cells)+length(cells2));
                    if(theCell.tdie+1+bindex < maxTime)
                        fprintf('Cell ID: %d was going to die beyond the max time, reducing to max time!\n', theCell.id)
                        theCell.tdie=maxTime-1-bindex;
                    end
                    fprintf('Cell ID: %d is dying \n', theCell.id)


                    numdeaths= numdeaths+1;
                    if(ceil(theCell.tdie/60)>size(sol.Tdies,2))
                       fprintf('Cell ID: %d had Tdie beyond the maximum time so reducing\n', theCell.id)
                       theCell.tdie=size(sol.Tdies,2)*60;
                    end
                    
                    sol.Tdies(theCell.gen,ceil(theCell.tdie/60))=sol.Tdies(theCell.gen,ceil(theCell.tdie/60))+1;
                    sol.deaths(end+1)=ceil(theCell.tdie/60);
                   
                    sol.tn(theCell.gen) = sol.tn(theCell.gen)+1;
                    if (theCell.tdie < 36*60 &&theCell.tdie > 12*60) || (theCell.gen == 1 && (theCell.tdie < 48*60 &&theCell.tdie > 24*60))
                        sol.tn24(theCell.gen) = sol.tn24(theCell.gen) +1;
                        sol.h24counts(theCell.gen) = sol.h24counts(theCell.gen) +1;
                    end

                   
                    sol.TdieTimes{theCell.gen}{end+1}=theCell.tdie;
                    sol.TdieMothers{theCell.gen}{end+1}=theCell.parent;
                    nondividers=nondividers+1;
                    cells(1)=[];
                    

                    if totalCellNumberCurrentlyProcessed+length(cellsToProcess)>size(sol.lineageInfo,2)

                        sol.lineageInfo=[sol.lineageInfo,zeros(size(sol.lineageInfo,1),length(cellsToProcess))];
                    end

                    ceil(theCell.birthday/30);
                    ceil(theCell.tdie/30);
                    totalCellNumberCurrentlyProcessed;
                    birthday=ceil(theCell.birthday/30);
                    deathTime=ceil(theCell.tdie/30)+birthday;
                    birthday=birthday+1;
                    

                    sol.lineageInfo(1,totalCellNumberCurrentlyProcessed)= theCell.id;
                    sol.lineageInfo(2,totalCellNumberCurrentlyProcessed)=theCell.parent;
                    sol.lineageInfo(3,totalCellNumberCurrentlyProcessed)=theCell.birthday+theCell.tdie;
                    
                    totalCellNumberCurrentlyProcessed=totalCellNumberCurrentlyProcessed+1;
                    
                    
                elseif (theCell.tdiv+1+bindex < maxTime)
                    %cell divided
                    cell_count=cell_count+1;
                    sol.tp(theCell.gen) = sol.tp(theCell.gen)+1;
                    if (theCell.tdiv < 36*60 &&theCell.tdiv > 12*60) || (theCell.gen == 1 && (theCell.tdiv < 48*60 &&theCell.tdiv > 24*60))
                        sol.tp24(theCell.gen) = sol.tp24(theCell.gen) +1;
                        sol.h24counts(theCell.gen) = sol.h24counts(theCell.gen) +1;
                    end
                    sol.TdecideTimes{theCell.gen}{end+1}=theCell.tdecide;
                    sol.TdecideMothers{theCell.gen}{end+1}=theCell.parent;

                    sol.fs(theCell.gen)=sol.fs(theCell.gen)+1;
                    %fprintf(1,'A cell divided at time %f it was %f minutes old. Total cells %d\n',theCell.tdiv+theCell.birthday,theCell.tdiv,length(cells)+length(cells2));
                    numdivs = numdivs+1;
                    sol.Tdivs(theCell.gen,ceil(theCell.tdiv/60))=sol.Tdivs(theCell.gen,ceil(theCell.tdiv/60))+1;
                    sol.divs(end+1)=ceil(theCell.tdiv/60);

                    sol.TdivTimes{theCell.gen}{end+1}=theCell.tdiv;
                    sol.TdivMothers{theCell.gen}{end+1}=theCell.parent;

                    dividers=dividers+1;
                    r = 1;
                    
                    currentCells2Length=size(cells2);
                    
                    dcell.birthday=theCell.tdiv+theCell.birthday;  % start at division time
                    dcell.gen = min(theCell.gen+1,maxGens);
                    dcell.id = cell_id;
                    cell_id=cell_id+1;
                    dcell.parent = theCell.id;
                    cells2{end+1} = dcell;  % append
                    

                    %Daughter 2

                     %update params
                    dcell2.birthday=theCell.tdiv+theCell.birthday;  % start at division time
                    dcell2.gen = min(theCell.gen+1,maxGens);
                    dcell2.id = cell_id;
                    cell_id=cell_id+1;
                    dcell2.parent = theCell.id;
                    %dcell2.v.OUTPUT2 = [];
                    cells2{end+1} = dcell2;  % append
                    
                    newCells2Length=size(cells2);
                    
                    if newCells2Length~=currentCells2Length+2
                       fprintf('Cell ID: %d divided but did not produce 2 daughter cells!\n', theCell.id)
                    end
                    
        if totalCellNumberCurrentlyProcessed+length(cellsToProcess)>size(sol.lineageInfo,2)
            %we need to add more space for new cell timecourses to
            %be stored.
            sol.lineageInfo=[sol.lineageInfo,zeros(size(sol.lineageInfo,1),length(cellsToProcess))];

        end



                    ceil(theCell.birthday/30);
                    ceil(theCell.tdie/30);
                    totalCellNumberCurrentlyProcessed;

                    birthday=ceil(theCell.birthday/30);
                    deathTime=ceil(theCell.tdiv/30)+birthday;
                    birthday=birthday+1;
                    
                    sol.lineageInfo(1,totalCellNumberCurrentlyProcessed)= theCell.id;
                    sol.lineageInfo(2,totalCellNumberCurrentlyProcessed)=theCell.parent;
                    sol.lineageInfo(3,totalCellNumberCurrentlyProcessed)=theCell.birthday+theCell.tdiv;
                    
                    totalCellNumberCurrentlyProcessed=totalCellNumberCurrentlyProcessed+1;
                    cells(1)=[];
                else % simulation ended
                    fprintf('Cell neither divided nor died... something wrong!');
                    cells(1)=[];
                end
            end
            sol.divbag{end+1}=sol.divs;
            sol.diebag{end+1}=sol.deaths;
            sol.decidebag{end+1}=sol.decides;

            %cells = cells2;
            %let's save the cells in arrays of no more than 250
            if length(cells2)<1
                fprintf(1,'\nNo Cells To Save\n');
            elseif length(cells2)<250
                experiment_label_Cells=sprintf('Cells-%s.mat',datestr(now,'mmmm dd, yyyy HH-MM-SS-FFF'));
                fileToSave=fullfile('unprocessedCells',experiment_label_Cells);
                cells=cells2;
                save(fileToSave,'cells');
                fprintf(1,'\nSaving %d New Unprocessed Cells to %s\n', length(cells2),fileToSave); 
            else
                numberOfFiles=0;
                for cellIndex=1:250:length(cells2)
                    experiment_label_Cells=sprintf('Cells-%s.mat',datestr(now,'mmmm dd, yyyy HH-MM-SS-FFF'));
                    fileToSave=fullfile('unprocessedCells',experiment_label_Cells);
                    indexToSaveFrom=cellIndex;
                    indexToSaveTo=cellIndex+249;
                    if length(cells2)<indexToSaveTo
                        indexToSaveTo=length(cells2);
                    end
                    variableToSave=cells2(indexToSaveFrom:indexToSaveTo);
                    cells=variableToSave;
                    save(fileToSave,'cells');
                    numberOfFiles=numberOfFiles+1;
                end
                fprintf(1,'\nSaved %d New Unprocessed Cells to %d files\n', length(cells2),numberOfFiles); 
            end
            if totalCellNumberCurrentlyProcessed+length(cellsToProcess)>size(sol.lineageInfo,2)
                %we need to add more space for new cell timecourses
                %to be stored.
                 sol.lineageInfo=[sol.lineageInfo,zeros(size(sol.lineageInfo,1),length(cellsToProcess))];
            end
            
            fileToSave=fullfile('Checkpoints', 'solutionOut.mat');
            save(fileToSave,'sol');
            %fprintf(1,'AMass=%3.3f, AcPARP=%3.3f, ACD=%3.3f, AGM=%3.3f, ARelA=%3.3f, AcRel=%3.3f, Amyc=%3.3f,\nAbcl2=%3.3f Divs=%d, Deaths=%d, Decides=%d,RelA+=%0.3f, cRel+=%0.3f, ATdiv=%3.2f MinTdiv=%3.2f ATdie=%3.2f MinTdie=%3.2f Cells=%d\n',(a_mass/real_count),(a_cparp/real_count),(a_CD/real_count), (a_GM/real_count),(a_RelA/real_count), (a_cRel/real_count),(a_myc/real_count), (a_bcl2/real_count),numdivs,numdeaths,numdecides,(numRelAPositive/real_count),(numcRelPositive/real_count),mean(sol.divs),min(sol.divs),mean(sol.deaths),min(sol.deaths),real_count);
            fprintf(1,'\nSaved Solution Checkpoint to %s\n',fileToSave);
            %clear sol;
            fprintf(1,'\n Moving file to processed folder: %s\n',fullfile('processedCells',cellsToProcess(k).name));
            movefile(fullfile('unprocessedCells',cellsToProcess(k).name),fullfile('processedCells',cellsToProcess(k).name));
            
            %TODO: code here to write the actual time course of each species in each cell to a
            %folder for analysis
            
        end
    end
        
    fprintf(1,'Processing stats\n');
    
    sol.lineageInfo( :, ~any(sol.lineageInfo,1) ) = [];
    %Post processing of stats
    for i=1:maxGens
        sol.counts(:,i)=sol.counts(:,i)-1;
    end
    accuracies=zeros(maxGens,1);
    logErrors=zeros(maxGens,2);
    statistics=zeros(maxGens,20);
    for g=1:maxGens
        if sol.integralCounts(g) > 0
            %lets compute the stats
            sol.fs(g)=sol.fs(g)/sol.integralCounts(g);
            sol.gs(g)=sol.gs(g)/sol.integralCounts(g);
            sol.tp(g)=sol.tp(g)/sol.integralCounts(g);
            sol.tn(g)=sol.tn(g)/sol.integralCounts(g);
            sol.fp(g)=sol.fp(g)/sol.integralCounts(g);
            sol.fn(g)=sol.fn(g)/sol.integralCounts(g);
            sol.tp24(g)=sol.tp24(g)/sol.h24counts(g);
            sol.tn24(g)=sol.tn24(g)/sol.h24counts(g);
            sol.fp24(g)=sol.fp24(g)/sol.h24counts(g);
            sol.fn24(g)=sol.fn24(g)/sol.h24counts(g);
            statistics(g,1)=sol.integralCounts(g);
            statistics(g,2)=sol.gs(g);
            statistics(g,3)=sol.fs(g);
            statistics(g,4)=sol.tp(g);
            statistics(g,5)=sol.tn(g);
            statistics(g,6)=sol.fp(g);
            statistics(g,7)=sol.fn(g);
            accuracies(g)=(sol.tp(g)+sol.tn(g));
            statistics(g,8)=accuracies(g);
            if ~ isempty(sol.divbag{g})
                sol.maxDivGen=g;
                %lets fit a lognormal to the divs
                vector = sol.divbag{g};
                [parmhat,parmci] = lognfit(vector(:));
                [M,V]=lognstat(parmhat(1),parmhat(2));
                TdivFits(g,1)=M;
                TdivFits(g,2)=sqrt(V);
                [Mlo,Vlo]=lognstat(parmci(1,1),parmci(2,2));
                [Mhi,Vhi]=lognstat(parmci(1,2),parmci(2,1));
                TdivFits(g,3)=Mlo;
                TdivFits(g,4)=Mhi;
                TdivFits(g,5)=sqrt(Vlo);
                TdivFits(g,6)=sqrt(Vhi);
                logErrors(g,1)=(((Mhi-Mlo)/M)+((Vhi-Vlo)/V))/2;
                for i = 1:6
                    statistics(g,8+i)=TdivFits(g,i);
                end
            end
            if ~ isempty(sol.diebag{g}) 
                sol.maxDieGen=g;
                %lets fit a lognormal to the divs
                vector = sol.diebag{g};
                [parmhat,parmci] = lognfit(vector(:));
                [M,V]=lognstat(parmhat(1),parmhat(2));
                TdieFits(g,1)=M;
                TdieFits(g,2)=sqrt(V);
                [Mlo,Vlo]=lognstat(parmci(1,1),parmci(2,2));
                [Mhi,Vhi]=lognstat(parmci(1,2),parmci(2,1));
                TdieFits(g,3)=Mlo;
                TdieFits(g,4)=Mhi;
                TdieFits(g,5)=sqrt(Vlo);
                TdieFits(g,6)=sqrt(Vhi);
                logErrors(g,2)=(((Mhi-Mlo)/M)+((Vhi-Vlo)/V))/2;
                for i = 1:6
                    statistics(g,14+i)=TdieFits(g,i);
                end
            end
        end    
    end
    sol.statistics = statistics;
    sol.logErrors = logErrors;
    sol.TdivFits = TdivFits;
    sol.TdieFits = TdieFits;   
end

function saveSolutions(solutions,N,maxTime,maxGens,label,paramString)
    experiment_label=sprintf('%s %s',label,datestr(now,'mmmm dd, yyyy HH-MM-SS-FFF'));
    mkdir(experiment_label);
    copyfile('*.m',experiment_label);
    ts = 1:30:maxTime;
    ts=ts./60;
    totals = zeros(length(solutions),length(ts));
    for r = 1:length(solutions)
        for t = 1:length(ts)
            totals(r,t) = sum(solutions{r}.counts(t,:));
        end
    end
    handle = fopen(sprintf('%s\\Parameters.txt',experiment_label),'w+');
    fprintf(handle,paramString);
    outarray = zeros((length(solutions)+1)*(maxGens+1)+1,length(ts));
    outarray(1,:) = ts';
    for g = 1: maxGens
       means = zeros(length(ts),1);
       for r = 1: length(solutions)
            means=means+solutions{r}.counts(:,g);
       end
       outarray(g+1,:)=means(:)./length(solutions);
    end
    outarray(maxGens+2,:)=sum(outarray(2:g+1,:));
    for r = 1: length(solutions)
        for g = 1: maxGens
            outarray((r)*(maxGens+1)+g+1,:)=solutions{r}.counts(:,g);
        end
        outarray((r)*(maxGens+1)+maxGens+2,:)=totals(r,:);
    end
    csvwrite(sprintf('%s\\counts.csv',experiment_label),outarray');


    mkdir(fullfile(experiment_label,'MetaboliteTimeCourses'));
    
    for r= 1: length(solutions)   
        csvwrite(fullfile(experiment_label,'MetaboliteTimeCourses',strcat('lineageInfo-rep',num2str(r),'.CSV')),solutions{r}.lineageInfo);
    end
    
    
    outarray = zeros(maxGens,(length(solutions)+1)*9);
    for r = 1: length(solutions)
        for g = 1: maxGens
            outarray(g,(r)*9+1)=solutions{r}.fs(g);
            outarray(g,(r)*9+2)=solutions{r}.tp(g);
            outarray(g,(r)*9+3)=solutions{r}.fp(g);
            outarray(g,(r)*9+4)=solutions{r}.tn(g);
            outarray(g,(r)*9+5)=solutions{r}.fn(g);
            outarray(g,(r)*9+6)=solutions{r}.tp24(g);
            outarray(g,(r)*9+7)=solutions{r}.fp24(g);
            outarray(g,(r)*9+8)=solutions{r}.tn24(g);
            outarray(g,(r)*9+9)=solutions{r}.fn24(g);
            outarray(g, 1)=outarray(g, 1)+solutions{r}.fs(g)/length(solutions);
            outarray(g, 2)=outarray(g, 2)+solutions{r}.tp24(g)/length(solutions);
            outarray(g, 3)=outarray(g, 3)+solutions{r}.fp24(g)/length(solutions);
            outarray(g, 4)=outarray(g, 4)+solutions{r}.tn24(g)/length(solutions);
            outarray(g, 5)=outarray(g, 5)+solutions{r}.fn24(g)/length(solutions);
            outarray(g, 6)=outarray(g, 6)+(solutions{r}.tp24(g)/(solutions{r}.tp24(g)+solutions{r}.fp24(g)))/length(solutions);
            outarray(g, 7)=outarray(g, 7)+(solutions{r}.fp24(g)/(solutions{r}.tp24(g)+solutions{r}.fp24(g)))/length(solutions);
            outarray(g, 8)=outarray(g, 8)+(solutions{r}.tn24(g)/(solutions{r}.tn24(g)+solutions{r}.fn24(g)))/length(solutions);
            outarray(g, 9)=outarray(g, 9)+(solutions{r}.fn24(g)/(solutions{r}.tn24(g)+solutions{r}.fn24(g)))/length(solutions);

        end
    end
    csvwrite(sprintf('%s\\Fs.csv',experiment_label),outarray);    
    handle = fopen(sprintf('%s\\FateTimes.csv',experiment_label),'w+');
    for r = 1:length(solutions)
        for g = 1:maxGens
            fprintf(handle,',,%dTdec%d,,%dTdiv%d,,%dTdie%d',r,g,r,g,r,g);
        end
    end
    fprintf(handle,',AllTdec0,AllTdiv0,AllTdie0,AllTdec1+,AllTdiv1+,AllTdie1+\n');
    AllTdec0 = cell(1);
    AllTdiv0 = cell(1);
    AllTdie0 = cell(1);
    AllTdec1 = cell(1);
    AllTdiv1 = cell(1);
    AllTdie1 = cell(1);
    for r = 1: length(solutions)
        for t = 1:numel(solutions{r}.TdecideTimes{1})
            if numel(solutions{r}.TdecideTimes{1}{1}) > 0
                AllTdec0{end+1} = solutions{r}.TdecideTimes{1}{t};
            end
        end
        for t = 1:numel(solutions{r}.TdivTimes{1})
            if numel(solutions{r}.TdivTimes{1}{1}) > 0
                AllTdiv0{end+1} = solutions{r}.TdivTimes{1}{t};
            end
        end
        for t = 1:numel(solutions{r}.TdieTimes{1})
            if numel(solutions{r}.TdieTimes{1}{1}) > 0
                AllTdie0{end+1} = solutions{r}.TdieTimes{1}{t};
            end
        end

        for g = 2:maxGens
            for t = 1:numel(solutions{r}.TdecideTimes{g})
                if numel(solutions{r}.TdecideTimes{g}{t}) > 0
                    AllTdec1{end+1} = solutions{r}.TdecideTimes{g}{t};
                end
            end
            for t = 1:numel(solutions{r}.TdivTimes{g})
                if numel(solutions{r}.TdivTimes{g}{t}) > 0
                    AllTdiv1{end+1} = solutions{r}.TdivTimes{g}{t};
                end
            end
            for t = 1:numel(solutions{r}.TdieTimes{g})
                if numel(solutions{r}.TdieTimes{g}{t}) > 0
                    AllTdie1{end+1} = solutions{r}.TdieTimes{g}{t};
                end
            end
        end
    end
    for row = 1:100000
       rowcount=0;
       for r = 1: length(solutions)
            for i = 1:maxGens
                if row <= numel(solutions{r}.TdecideTimes{i}) 
                   fprintf(handle,',%d,%2.2f',solutions{r}.TdecideMothers{i}{row},solutions{r}.TdecideTimes{i}{row}/60.0);
                   rowcount=rowcount+1;
                else
                    fprintf(handle,',,');
                end
                if row <= numel(solutions{r}.TdivTimes{i})
                   fprintf(handle,',%d,%2.2f',solutions{r}.TdivMothers{i}{row},solutions{r}.TdivTimes{i}{row}/60.0);
                   rowcount=rowcount+1;
                else
                    fprintf(handle,',,');
                end
                if row <= numel(solutions{r}.TdieTimes{i})
                   fprintf(handle,',%d,%2.2f',solutions{r}.TdieMothers{i}{row},solutions{r}.TdieTimes{i}{row}/60.0);
                   rowcount=rowcount+1;
                else
                    fprintf(handle,',,');
                end
            end
       end
       if row <= numel(AllTdec0)
           fprintf(handle,',%2.2f',AllTdec0{row}/60.0);
           rowcount=rowcount+1;
       else
           fprintf(handle,',');
       end
       if row <= numel(AllTdiv0)
           fprintf(handle,',%2.2f',AllTdiv0{row}/60.0);
           rowcount=rowcount+1;
       else
           fprintf(handle,',');
       end
       if row <= numel(AllTdie0)
           fprintf(handle,',%2.2f',AllTdie0{row}/60.0);
           rowcount=rowcount+1;
       else
           fprintf(handle,',');
       end
       if row <= numel(AllTdec1)
           fprintf(handle,',%2.2f',AllTdec1{row}/60.0);
           rowcount=rowcount+1;
       else
           fprintf(handle,',');
       end
       if row <= numel(AllTdiv1)
           fprintf(handle,',%2.2f',AllTdiv1{row}/60.0);
           rowcount=rowcount+1;
       else
           fprintf(handle,',');
       end
       if row <= numel(AllTdie1)
           fprintf(handle,',%2.2f',AllTdie1{row}/60.0);
           rowcount=rowcount+1;
       else
           fprintf(handle,',');
       end

       fprintf(handle,'\n');
       if rowcount == 0
           break;
       end
    end
    fclose(handle);
    %csvwrite(sprintf('%s\\FateTimes.csv',experiment_label),[cell2mat(sol.TdecideTimes),cell2mat(sol.TdivTimes),cell2mat(sol.TdieTimes)]);
    %end
    %save Tdecides, Tdivs, Tides 
    %fprintf(1,'Saved all masses and counts to %s\n',experiment_label);
end


% Make a copy of a handle object.
function new = copy(this)
    % Instantiate new object of the same class.
    new = feval(class(this));
    % Copy all non-hidden properties.
    p = fieldnames(struct(this));
    for i = 1:length(p)
        new.(p{i}) = this.(p{i});
    end
end

function c2 = duplicate(sol)
    c2 = struct;   
    %parameters= {'Tdiv0mean';'Tdiv0var';'Tdie0mean';'Tdie0var';'Tdiv1pmean';'Tdiv1pvar','pF'};
    
    c2.Tdiv0mean = sol.Tdiv0mean;
    c2.Tdiv0var = sol.Tdiv0var;
    c2.Tdie0mean = sol.Tdie0mean;
    c2.Tdie0var = sol.Tdie0var;
    c2.Tdiv1pmean = sol.Tdiv1pmean;
    c2.Tdiv1pvar = sol.Tdiv1pvar;
    c2.pF = sol.pF;

    c2.maxTime=sol.maxTime;  
end



function v = getRandomCell(v)
        %--- Randomization of NFkB syn/deg params
        for i = [1,2,3,4,5,11,12,13,14]          
            for j = 1:size(v.pi(i,:),2)
                v.pi(i,j)=max(0,normrnd(v.pi(i,j),v.pi(i,j)*v.RATE_CV));
            end
        end
        for i = [1,2,3,4,5]         
            for j = 1:size(v.pm(i,:),2)
                v.pm(i,j)=max(0,normrnd(v.pm(i,j),v.pm(i,j)*v.RATE_CV));
            end
        end
        for i = 9:12          
            for j = 1:size(v.pd(i,:),2)
                v.pd(i,j)=max(0,normrnd(v.pd(i,j),v.pd(i,j)*v.RATE_CV));
            end
        end
        %--- apoptosis syn/deg
        for i = 71:115
            v.k(i)= max(0,normrnd(v.k(i),v.k(i)*v.RATE_CV));
        end
        %--- cell cycle syn/deg
        for i = [8,9,12:15,18:34,47:67,74:76,78:86]
            v.k2(i)= max(0,normrnd(v.k2(i),v.k2(i)*v.RATE_CV));
        end
        %--- cell cycle species randomization
        theMask = zeros(size(v.SPECIES{1},1),1);
        theMask(137:142) = 1;
        v.SPECIES{1} = getRandomSpeciesMaskLognormal(v.SPECIES{1},theMask,v.CONC_CV,0);
end


function v2 = getDaughterCell(v,vo,r)
        v2 = copy(v);
        for i = [1,2,3,4,5,11,12,13,14]          
            for j = 1:size(v.pi(i,:),2)
                v2.pi(i,j)=max(0,(normrnd(v.pi(i,j),v.pi(i,j)*v.RATE_CV)+normrnd(vo.pi(i,j),vo.pi(i,j)*vo.RATE_CV))/2);
            end
        end
        for i = [1,2,3,4,5]         
            for j = 1:size(v.pm(i,:),2)
                v2.pm(i,j)=max(0,(normrnd(v.pm(i,j),v.pm(i,j)*v.RATE_CV)+normrnd(vo.pm(i,j),vo.pm(i,j)*vo.RATE_CV))/2);
            end
        end
        for i = 9:12          
            for j = 1:size(v.pd(i,:),2)
                v2.pd(i,j)=max(0,(normrnd(v.pd(i,j),v.pd(i,j)*v.RATE_CV)+normrnd(vo.pd(i,j),vo.pd(i,j)*vo.RATE_CV))/2);
            end
        end
        %--- apoptosis syn/deg
        for i = 71:115
            v2.k(i,j)=max(0,(normrnd(v.k(i),v.k(i)*v.RATE_CV)+normrnd(vo.k(i),vo.k(i)*vo.RATE_CV))/2);
        end
        %--- cell cycle syn/deg
        for i = [8,9,12:15,18:34,47:67,74:76,78:86]
            v2.k2(i,j)=max(0,(normrnd(v.k2(i),v.k2(i)*v.RATE_CV)+normrnd(vo.k2(i),vo.k2(i)*vo.RATE_CV))/2);
        end
        v2.SPECIES{1}(132)=v.SPECIES{1}(132)*r;
        v2.SPECIES{1}(134)=v.SPECIES{1}(134)*r;
        %==== IKK Input Curve
        if vo.IKK_CV > 0
            sigma= sqrt(log(1+(vo.IKK_CV^2)));
            mu= log(140)-0.5*sigma^2; 
            rnd = lognrnd(mu,sigma);
            v2.TOTAL_IKK=(v.TOTAL_IKK+rnd)/2;
        end
end

     % NFKB_CYCD_T NFKB_BCL2_T  NFKB_MYC_T    GROWTH_T  
     % RATE_CV CONC_CV PARTITION_CV VOL_CV IKK_CV  
     % GMSyn  GMDeg  MassGrowth MassDecay 
     % CYCDtSyn CYCDtDeg BCL2Syn BCL2tDeg 
     % MYCSyn MYCDeg mMycSyn mMycDeg L
     % IKK STIMULUS, Crel monomer,cRelFeedback,eps (Ribosome modifier);IKKt
function c2= experimentConditions(maxTime,parameters)
    c2 = struct;
    %parameters= {'Tdiv0mean';'Tdiv0var';'Tdie0mean';'Tdie0var';'Tdiv1pmean';'Tdiv1pvar','pF'};
    
    c2.Tdiv0mean = parameters(1);
    c2.Tdiv0var = parameters(2);
    c2.Tdie0mean = parameters(3);
    c2.Tdie0var = parameters(4);
    c2.Tdiv1pmean = parameters(5);
    c2.Tdiv1pvar = parameters(6);
    c2.pF = parameters(7);
    c2.maxTime=maxTime;
end


function [kinit]=getRandomRatesMaskNormal(k0,mask,CV)
    kinit = zeros(length(k0),1);
    for cc=1:length(k0)
        factor = 1;
        if mask(cc) == 1
            factor = normrnd(1,double(sqrt(CV)));
        end
        kinit(cc)=factor*k0(cc);
    end
end

function [x0aa]= getRandomSpeciesMaskLognormal(x0,mask,CV,GaussianNoise)
    x0aa = zeros(length(x0),1);
    for cc=1:length(x0)
        factor = 1;
        if GaussianNoise > 0
            factor = normrnd(1,double(GaussianNoise));
        end
        if CV >0
            sigma = sqrt(log(CV*CV+1));
        else
            sigma = 0;
        end
        mu= log(max(0,x0(cc))); 
        if mask(cc) == 1
            rnd = lognrnd(mu,sigma);
            if mu==0 
                rnd=0;
            end
            x0aa(cc)=rnd*factor;
         
        else
            x0aa(cc)=x0(cc)*factor;
        end
    end
end


