function v=initial_parameters8(condition)

    v=struct;

    %==== Simulation Parameters
    v.START_TIME      = 0;
    v.SIM_TIME        = condition.maxTime*60; % seconds of stimulation phase
    v.PLOT_FLAG       = false;   % Plot results?
    v.PLOT_POS        = false;  % Used in plot function. default = false 
    v.DISP            = false;   % Display simulation text?
    v.SEC_RUN         = false;  % Run in seconds(true) or minutes (false)
    v.CONSTRAINT_FLAG = true;  % Check results against constraints?
    v.CONSTRAINT_LOOP = false;  % True to return only constraint results
    v.RATE_MODS       = {};     % set by input argument (below)
    v.CYCD_THRESHOLD  = condition.NFKB_CYCD_T; % nm (Amount of C50 in the nucleus)
    v.BCL2_THRESHOLD = condition.NFKB_BCL2_T; % nm
    v.MYC_THRESHOLD = condition.NFKB_MYC_T; % nm
    v.GROWTH_THRESHOLD = condition.GROWTH_T; % nm
    v.RATE_CV              = condition.RATE_CV; % sd of normal
    v.CONC_CV            =condition.CONC_CV;  % sd of lognormal
    v.PARTITION_CV = condition.PARTITION_CV;  % sd of multiplier around 0
    v.IKK_CV = condition.IKK_CV;
    v.pre_RATE_CV = condition.pre_RATE_CV;
    v.pre_CONC_CV = condition.pre_CONC_CV;
    %v.pre_IKK_CV = condition.pre_IKK_CV;

    %==== IKK Input Curve
    if condition.IKK_CV > 0
        sigma= sqrt(log(1+(condition.IKK_CV^2)));
        mu= log(condition.TOTAL_IKK)-0.5*sigma^2; 
        rnd = lognrnd(mu,sigma);
        v.TOTAL_IKK=rnd;
    else
        v.TOTAL_IKK=condition.TOTAL_IKK;
    end
    
    v.BASAL_IKK       = .001;
ikk_curves        = {'CpG250','CpG10','CpG2'};     ikk_curve_num     = condition.STIMULUS;  % index of ikk curve to use (1 ... 2)
    v.IKK_TYPE        = ikk_curves{ikk_curve_num};

%==== Number of species and # components for each
    v.IKBS            = 4; % Number of IkBs
    v.IKB_COMP        = 3; % Number of components per IkB
    v.DIMERS          = 4; % Number of NFkB Dimers 
    v.DIMER_COMP      = 10;% Number of components per Dimer 
    v.MONOMERS        = 3; % Number of Monomers  
    v.MONOMER_COMP    = 3; % Number of components per Monomer
    v.APOPTOSIS       = 58; % Number of death species
    v.CELL_CYCLE       = 25; %25 species

%==== Species Knockouts  1 = present / 0 = knocked-out
    v.IKB_KO          = logical([1;1;1;0]); % IkBa ; b ; e ; d
    v.MONOMER_KO      = logical([1;1;condition.CREL]);     % RelA ; p50; cRel
    v.DIMER_KO        = logical([1;1;1;1]);   % AA ; A50 ; 5050; C50
    
    v.OUTPUT1 = []; % phase 1 (equilibrium) numerical results
    v.OUTPUT2 = []; % phase 2 (stimulated) numerical results
    
    if ~v.SEC_RUN
        v.START_TIME = floor(v.START_TIME/60);
        v.SIM_TIME   = floor(v.SIM_TIME/60); 
    end
 
    %==== Deal with variables passed into the run file
    %{
        Input variable is a cell array
        Each row contains a v struct field name and a replacement value
            ie: {'SIM_TIME', 3600} or {'v.IKK_TYPE' , 'TNF15p'}
        You cannot use the input to create a new struct field
        Likewise, fields set after this section of code cannot be changed
            (CURRENT_IKK, parameter lists, species names, etc)
        A special input field 'RATE_MODS' is used in the parameter function
            {'RATE_MODS',{[param #s],mod value}}
    %}

    %==== Run Setup Functions
    v=generate_ikkcurve(v); % Generate IKK Curve
    v=set_parameters(v,condition); % Reaction Rates/Parameters & Set Initial Values and Names
end

function v=generate_ikkcurve(v)
    % IKK library is in minutes so it has to be converted to seconds
    if v.SEC_RUN
        convert = 60; % 60 seconds per minute
        ikk_time = v.SIM_TIME;
    else
        convert = 1;
        ikk_time = v.SIM_TIME;
    end

    IKKmax=0.5;
    expn1 = 2;
    Kd1 = 50;
    expn2 = 1;
    if (strcmp(v.IKK_TYPE,'CpG250'))
        
        Kd2=2000;
        %values = [1 2 7 13 19 32  29  27  25  24  22  20     19     14    11     5     1] /100;
        %time = [0 15 30 45 60 90 120 240 360 600 1440 1440*2 1440*3 1440*4 1440*5 1440*6 1440*10]*convert; 
    elseif (strcmp(v.IKK_TYPE,'CpG10'))
        Kd2=1500;
        %values = [1 2 7 13 19 32  27  25  24  22  20  10     7      5    3     2     1] /100;
        %time = [0 15 30 45 60 90 120 240 360 600 1440 1440*2 1440*3 1440*4 1440*5 1440*6 1440*10]*convert; 
    elseif (strcmp(v.IKK_TYPE,'CpG2'))
     
        values = [1 2 7 13 19 32  29  27  25  24  22  20     19     14    11     5     1] /100;
        time = [0 15 30 45 60 90 120 240 360 600 1440 1440*2 1440*3 ...
                1440*4 1440*5 1440*6 1440*10]*convert;

    else
        error('nfkb_run_61:generate_ikk_curve() Incorrect IKK input name');
    end
    v.CURRENT_IKK = interp1(time, values, 0:time(end),'pchip');


end


function v=set_parameters(v,condition)
%{ 
        Parameters use seconds as their time unit
            % Complex Association : 1 / (nM * sec)
            % Complex Dissociation : 1 / (sec)
            % mRNA and Protein Degradation : 1 / (sec)
            % IKK Mediated Degradation : 1 / (nM * sec)
            % Localization (nuclear import and export) : 1 / (sec)
            % Constitutive transcription rate: nM / sec
            % Inducible transcription modifier : unitless
        To simulate in minutes, the following code scale them. Doing so 
        can greatly reduce the size of the results array and can thus 
        benefit repeated/looped sets of simulations.
        %}
            
        if v.SEC_RUN % Simulate in seconds
            t = 1;  % no change. Rates are by default in seconds
        else
            t = 60; % Convert to minutes (60sec/min)
        end
        
        %==== Initialize Parameter Lists
        % These arrays are separated by reaction type. The first number is
        % the number of rate constants per type. The ODE file uses these
        % rate constants in this exact order, so make sure that you update
        % the ODE file if you change this order.
        v.pi         = zeros(14,v.IKBS);               % IkBs 
        v.pm         = zeros(8,v.MONOMERS);            % Monomers 
        v.pd         = zeros(12,v.DIMERS);             % Dimer-only 
        v.pdi        = zeros(7,v.DIMERS,v.IKBS);       % Dimer with IKB 
        v.pdm        = zeros(1,v.DIMERS,v.MONOMERS);   % Dimer with Monomer

        %==== IkB reaction rate constants
        % 1-14 ikba, 15-28 b, 29-42 e, 43-56 d
        %           ikba      ikbb    ikbe    ikbd
        
        v.pi(1,:) = [1.5e-5; 1e-5;  6e-7*2;   6e-8    ]*t;% const txn 
                        % Fit so IkBs are ~ 270, 70, 30nM respectively
        v.pi(2,:) = [7.3e-4;  4.8e-5; 6.4e-5; 3.2e-5  ]*t;% mRNA deg 
                        % half-lives... 15min, 4hr, 3hr (Shih ActD data)
        v.pi(3,:) = [.2;      .2;     .2;     .2     ]*t;% tsl rate
                        % (30 nt/sec)/(150nt spacing) = .2 / sec
                                       
        v.pi(4,:) = [2e-3;    2e-3;   1.925e-4;   2.4e-5  ]*t; % Free IkB protein degradation in cytoplasm 
        v.pi(5,:) = v.pi(4,:);                             % Free IkB protein degradation in nucleus
                        % Free deg rates measured by O'Dea MSB 2007, ikbe
                        % rates estimated by Karen's experimental
                        % data(2012)
                     
                                                    
        v.pi(6,:) = [1e-3;  1.5e-4; 7.5e-4; 7.5e-4    ]*t; % Nuclear import of free IkB
        v.pi(7,:) = [2e-4;    2e-4;   2e-4;   2e-4    ]*t; % Nuclear export of free IkB
                        % retained from Hoffmann Science 2002
        
        v.pi(8,:) = [0;     2700; 2700; 5400    ]/t; % NFkB-inducible txn delay 
                        % 37 min delay measured in Longo (in preparation) -
                        % changed to 45 min (RT) 
                        % 60 for IkBd (Basak Cell)
                        
        v.pi(9,:) = [1.1;     1.1;    1.1;    1     ]; % Hill Coeffients for inducible txn
        v.pi(10,:)= [150;   150;  150;  150   ]; % NFkB binding affinity to promoters, Kd (nM)
                                                 % Used in inducible txn reaction
        
        v.pi(11,:)= [1.5e-5;  5e-6; 3.75e-6; 1e-5  ]*t*1.5; % IKK mediated deg of free IkB changed ikbe to 4 fold less than ikba
        v.pi(12,:)= v.pi(11,:);                          % IKK mediated deg of bound IkB
                        % Assumed to be equal (communication from Erika
                        % Mathes from Gouri Ghosh's lab)
        
        v.pi(13,:)= [4e-6;  4e-6; 4e-6; 4e-6  ]*t;  % Deg of NFkB-bound IkB protein in cytoplasm
        v.pi(14,:)= [4e-6;  4e-6; 4e-6; 4e-6  ]*t;  % Deg of NFkB-bound IkB protein in nucleus

        
        constituitiveMultiplier = (1+(6/150))/(1+condition.cRelFeedback*(6/150)); % x = 1/K, K = line 289 in ode
        %==== NFkB monomer reaction rate constants
        %              RelA      p50       cRel
        v.pm(1,:) 	= [1.2e-6;   (1.2e-6)*constituitiveMultiplier;    (1.2e-6)*constituitiveMultiplier  ]*t; % constitutive transcription, assume w=10 for both p50 and c50 inducible, and given that the basal [a50]=4 and [c50]=2 and Kds are 150
        v.pm(2,:) 	= [4.8e-5;  4.8e-5;     4.8e-5  ]*t; % mRNA degradation
                        % half-lives... 4hr each (Shih ActD data) (4.8e-5)
                        
        v.pm(3,:)	= [.2;      .2;     .2]*t; % translation rate
                        % (30 nt/sec)/(150nt spacing) = .2mRNA / sec
                        
        v.pm(4,:)	= [3.85e-4;  3.85e-4;   3.85e-4  ]*t; % Degradation of free monomer in the cytoplasm
        v.pm(5,:)	= v.pm(4,:);               % Degradation of free monomer in the nucleus 
                        % no real data on monomer deg. Assumed to be short
        
        v.pm(6,:)   = [3600;    3600;   3600    ]/t; % inducible txn delay
        v.pm(7,:)   = [1;       1;      1]; % Hill Coefficient for inducible txn reaction
        v.pm(8,:)	= [150;     150;    150]; % NFkB binding affinity to promoters, Kd (nM)
                                           % Used in inducible txn reaction

        %==== NFkB Dimer-only reaction rate constants
        %              AA       A50     5050    C50
        v.pd(1,:)    = [1;      1;      2;      2];    % Mon #1 index (not a rate constant, but needed in ODE)
        v.pd(2,:)    = [1;      2;      2;      3];    % Mon #2 index (not a rate constant, but needed in ODE)
        v.pd(3,:)    = [1e-5;   3.16e-5; 3e-5; 3.16e-5]*t;   % Dimer association in cytoplasm
        v.pd(4,:)    = [1e-5;   3.16e-5; 3e-5; 3.16e-5 ]*t;     % Dimer association in nucleus
        v.pd(5,:)    = [8e-3;   3.16e-4; 9e-4;  3.16e-4]*t;   % Dimer dissociation in cytoplasm   
        v.pd(6,:)    = [8e-3/10;3.16e-4/10; 9e-4/10;    3.16e-4/10]*t;     % Dimer dissociation in nucleus, assumed to be stable because DNA bound-stable
                    % These rates picked to fit Gouri Ghosh's original
                    % binding data. 
                    %  Measured by G Ghosh AUC experiments
                 
        v.pd(7,:)    = [9e-2;   9e-2;   9e-2;   9e-2  ]*t;  % Nuclear import of dimer
        v.pd(8,:)    = [8e-5;   8e-5;   8e-5;   8e-5  ]*t;  % Nuclear export of dimer
        
        v.pd(9,:)    = [4e-6;   4e-6;   4e-6;   4e-6  ]*t;  % Protein degradation of free dimer in the cytoplasm
        v.pd(10,:)   = [4e-6;   4e-6;   4e-6;   4e-6  ]*t;  % Protein degradation of free dimer in the nucleus
        v.pd(11,:)   = [4e-6;   4e-6;   4e-6;   4e-6  ]*t;  % Protein degradation of IkB-bound dimer in the cytoplasm
        v.pd(12,:)   = [4e-6;   4e-6;   4e-6;   4e-6  ]*t;  % Protein degradation of IkB-bound dimer in the nucleus
    
        %==== NFkB Dimer-IKB reaction rate constants
        %              AA       A50     5050    C50
         v.pdi(1,:,:) = [2.24e-5 8.01e-5   0    5.01e-5; ...% Ikba : Association in cytoplasm				
                        5e-3  3.55e-6  0    3.55e-6; ...% Ikbb				
                        3.55e-6 2.24e-5   0 2.24e-5; ...% Ikbe				
                        1e-4    3e-3   0    3e-3]'*t;% Ikbd				

            
         v.pdi(3,:,:) = [4.47e-7  1e-5 0    8e-5;... % Ikba : Dissociation in cytoplasm 					
                        2e-5  2.82e-4 0     2.82e-4;... % Ikbb  					
                        2.82e-4  1e-4  0    4.47e-7;... % Ikbe					
                        1e-3    3e-3      0     3e-3]'*t;% Ikbd 					
                    
        v.pdi(2,:,:) = v.pdi(1,:,:);      %Association in nucleus (same as cyt)
                    
        v.pdi(4,:,:) = v.pdi(3,:,:);      %Dissociation in nucleus (same as cyt)

        v.pdi(5,:,:) = [4.6e-3  4.6e-3  0   4.6e-3;... % Ikba : Nuclear Import
                        4.6e-4  4.6e-4  0   4.6e-4;... % Ikbb
                        2.3e-3  2.3e-3  0   2.3e-3;... % Ikbe
                        2.3e-3  2.3e-3  0   2.3e-3]'*t;% Ikbd
       
        v.pdi(6,:,:) = [1.4e-2  1.4e-2  0   1.4e-2;... % Ikba : Nuclear Export
                        7e-3    7e-3    0   7e-3;... % Ikbb
                        7e-3    7e-3    0   7e-3;... % Ikbe
                        7e-3    7e-3    0   7e-3]'*t;% Ikbd
                    
                    
        v.pdi(7,:,:) = [25      200      0   1;... % Ikba : inducible parameter modifier
                        1       1       0   1;... % Ikbb     0 = no induction
                        25     25     0   250;... % Ikbe
                        200     200     0   0]';  % Ikbd
                    

        %==== NFkB Dimer-Monomer reaction rate constants
        %              AA      A50   5050 C50
        v.pdm(1,:,:) = [0      0      0     0;...   % RelA : inducible parameter modifier
                        0      condition.cRelFeedback      0     condition.cRelFeedback;...   % p50
                        0      condition.cRelFeedback      0     condition.cRelFeedback;]'*1; % cRel    

    %==== Adjust for Rate modifiers set in v.RATE_MODS
    % The user can pass this struct field as a function argument
    %  It identifies each parameter that is modified and the modifier
    %  value
    %  v.RATE_MODS(:,1) = param list identifier (pi,pm,pd,pdi,pdm)
    %  v.RATE_MODS(:,2) = vector of param numbers
    %  v.RATE_MODS(:,3) = modifier value

    for i = 1:size(v.RATE_MODS,1)
        switch lower(v.RATE_MODS{i,1})
            case {'pi'}
                v.pi(v.RATE_MODS{i,2}) = ...
                    v.pi(v.RATE_MODS{i,2}) * v.RATE_MODS{i,3};
            case {'pm'}
                 v.pm(v.RATE_MODS{i,2}) = ...
                    v.pm(v.RATE_MODS{i,2}) * v.RATE_MODS{i,3};
            case {'pd'}
                 v.pd(v.RATE_MODS{i,2}) = ...
                    v.pd(v.RATE_MODS{i,2}) * v.RATE_MODS{i,3};
            case {'pdi'}
                 v.pdi(v.RATE_MODS{i,2}) = ...
                    v.pdi(v.RATE_MODS{i,2}) * v.RATE_MODS{i,3};
            case {'pdm'}
                 v.pdm(v.RATE_MODS{i,2}) = ...
                    v.pdm(v.RATE_MODS{i,2}) * v.RATE_MODS{i,3};
            otherwise
                error('nfkb_run_60: improper RATE_MOD identifier');
        end
    end

    %====  Adjust knockout arrays and synthesis parameters
    % If the user has set knockouts above, this will set the synthesis
    % rates for the affected species to zero. It will also disable
    % dimer association for knocked out dimers.
    % Note: this does not affect initial values, so make sure you set a
    % knocked out species to 0 initial value.
    v.pi(1,:) = v.pi(1,:) .* v.IKB_KO'; %ko ikb txn
    v.pm(1,:) = v.pm(1,:) .* v.MONOMER_KO'; %ko monomer txn

    for i = 1:v.DIMERS % ko dimer if one of its monomers is ko'd
        if ~v.MONOMER_KO(v.pd(1,i),1) || ~v.MONOMER_KO(v.pd(2,i),1)
            v.DIMER_KO(i) = false;
        end        
    end
    
    %get initial concentrations and constants for cell cycle and apoptosis
    
    [x0a,ka,ca,xapo,kapo,xdapo] = apop_init_nopy();  % get initial concentrations and constants for apoptosis
    [x0c,kc,names] = getInitialCellCycle4(condition); % get initial cell cycle and NFkB connection params   
    v.activated = false;  %used when simulating each  module independently to specify the cell state (activated means surviving and dividing)
    v.k=ka;
    v.k2=kc;
    v.c=ca;
    x0a(1) = 0;
    v.DIMERS = 4;
    v.DIMERStext = {'AA','A50', '5050', 'C50'};
    v.numSpecies = v.IKB_COMP*v.IKBS + v.MONOMER_COMP*v.MONOMERS + v.DIMER_COMP*v.DIMERS;
    v.SPECIES{1}  = zeros(61,1); % all species start at zero nM by default in NFkB module
    v.SPECIES{1} = [v.SPECIES{1};x0a;x0c];
    v.SPECIES{2}  = { ...  % Component # 1-12 , 13-21 , 22-31 (AA), 32-41 (A50), 42-51(5050), 52-61(C50)
        % The suffixes are standardized
        %       _mRNA = mRNA transcript
        %       _cyt  = cytoplasmic-localized protein
        %       _nuc  = nuclear-localized protein
        % If you add any new species that don't fit in these
        % categories, just add your own tag.
        % The standardized names help later in the plotting functions.
        'tIkBa','IkBa', 'IkBan','tIkBb','IkBb','IkBbn','tIkBe','IkBe','IkBen','tIkBd','IkBd','IkBdn',...
        'tRelA', 'RelA','RelAn','tP50','P50','P50n','tcRel','cRel', 'cReln', ...                           
        'AA','AAn','IkBaAA','IkBaAAn','IkBbAA', 'IkBaAAn','IkBeAA','IkBeAAn', 'IkBdAA','IkBdAAn', ... 
        'A50','A50n','IkBaA50','IkBaA50n','IkBbA50','IkBbA50n','IkBeA50','IkBeA50n','IkBdA50','IkBdA50n',... 
        '5050','5050n','IkBa5050','IkBa5050n','IkBb5050','IkBb5050n','IkBe5050','IkBe5050n','IkBd5050','IkBd5050n'...
        'C50', 'C50n', 'IkBaC50', 'IkBaC50n', 'IkBbC50','IkBbC50n','IkBeC50', 'IkBeC50n', 'IkBdC50','IkBdC50n'...
        }';  
    v.SPECIES{2}= [v.SPECIES{2};xapo;names'];
    v.PHASE = 1; % Run without stimulation!
end


    

